==> search-ui-container-v2.2.7-1.tar.gz: package/lib/AcmLabels/AcmLabels.js <==
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AcmLabels = void 0;
/* eslint-disable @typescript-eslint/no-non-null-assertion */
var core_1 = require("@material-ui/core");
var react_core_1 = require("@patternfly/react-core");
require("@patternfly/react-core/dist/styles/base.css");
var react_1 = __importStar(require("react"));
var useStyles = core_1.makeStyles({
    label: {
        margin: 1,
        overflow: 'hidden',
    },
});
function AcmLabels(props) {
    var classes = useStyles();
    var labelsRecord = react_1.useMemo(function () {
        if (props.labels === undefined)
            return {};
        else if (Array.isArray(props.labels))
            return props.labels.reduce(function (labels, label) {
                var parts = label.split('=');
                /* istanbul ignore if */
                if (parts.length === 1) {
                    labels[parts[0]] = '';
                }
                else {
                    labels[parts[0]] = parts.slice(1).join('=');
                }
                return labels;
            }, {});
        else
            return props.labels;
    }, [props.labels]);
    var labels = react_1.useMemo(function () {
        return Object.keys(labelsRecord)
            .filter(function (key) { var _a; return !((_a = props.collapse) === null || _a === void 0 ? void 0 : _a.includes(key)); })
            .map(function (key) { return (labelsRecord[key] ? key + "=" + labelsRecord[key] : "" + key); });
    }, [labelsRecord, props.collapse]);
    var hidden = react_1.useMemo(function () {
        if (props.labels === undefined)
            return [];
        return Object.keys(labelsRecord)
            .filter(function (key) { var _a; return (_a = props.collapse) === null || _a === void 0 ? void 0 : _a.includes(key); })
            .map(function (key) { return (labelsRecord[key] ? key + "=" + labelsRecord[key] : "" + key); });
    }, [labelsRecord, props.collapse]);
    if (props.labels === undefined)
        return react_1.default.createElement(react_1.Fragment, null);
    return (react_1.default.createElement(react_core_1.LabelGroup, { style: props.style, numLabels: labels.length, collapsedText: props.collapsedText, expandedText: props.expandedText },
        labels.map(function (label) { return (react_1.default.createElement(react_core_1.Label, { key: label, className: classes.label, title: label }, label)); }),
        hidden.map(function (label) { return (react_1.default.createElement(react_core_1.Label, { key: label, className: classes.label, title: label }, label)); })));
}
exports.AcmLabels = AcmLabels;
//# sourceMappingURL=AcmLabels.js.map

==> search-ui-container-v2.3.6-7.tar.gz: package/lib/AcmLabels/AcmLabels.js <==
"use strict";
/* Copyright Contributors to the Open Cluster Management project */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AcmLabels = void 0;
var react_core_1 = require("@patternfly/react-core");
var react_1 = __importStar(require("react"));
function AcmLabels(props) {
    var labelsRecord = react_1.useMemo(function () {
        if (props.labels === undefined)
            return {};
        else if (Array.isArray(props.labels))
            return props.labels.reduce(function (labels, label) {
                var parts = label.split('=');
                /* istanbul ignore if */
                if (parts.length === 1) {
                    labels[parts[0]] = '';
                }
                else {
                    labels[parts[0]] = parts.slice(1).join('=');
                }
                return labels;
            }, {});
        else
            return props.labels;
    }, [props.labels]);
    var labels = react_1.useMemo(function () {
        return Object.keys(labelsRecord)
            .filter(function (key) { var _a; return !((_a = props.collapse) === null || _a === void 0 ? void 0 : _a.includes(key)); })
            .map(function (key) { return (labelsRecord[key] ? key + "=" + labelsRecord[key] : "" + key); });
    }, [labelsRecord, props.collapse]);
    var hidden = react_1.useMemo(function () {
        if (props.labels === undefined)
            return [];
        return Object.keys(labelsRecord)
            .filter(function (key) { var _a; return (_a = props.collapse) === null || _a === void 0 ? void 0 : _a.includes(key); })
            .map(function (key) { return (labelsRecord[key] ? key + "=" + labelsRecord[key] : "" + key); });
    }, [labelsRecord, props.collapse]);
    if (props.labels === undefined)
        return react_1.default.createElement(react_1.Fragment, null);
    return (react_1.default.createElement(react_core_1.LabelGroup, { style: props.style, numLabels: labels.length, collapsedText: props.collapsedText, expandedText: props.expandedText },
        labels.map(function (label) { return (react_1.default.createElement(react_core_1.Label, { key: label, title: label, variant: props.variant, color: props.color }, label)); }),
        hidden.map(function (label) { return (react_1.default.createElement(react_core_1.Label, { key: label, title: label, variant: props.variant, color: props.color }, label)); })));
}
exports.AcmLabels = AcmLabels;
//# sourceMappingURL=AcmLabels.js.map
